summaryrefslogtreecommitdiffstats
path: root/korundum/rubylib/examples/rbTDEHTMLPart.rb
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:07 -0600
commit3ed7c09d22a5f310a97516f5bab6068e5688a813 (patch)
tree23ba07d28f7fad17824db1fc40e9cf1ad4942480 /korundum/rubylib/examples/rbTDEHTMLPart.rb
parent3a8473ba2620b85b165b5a2fa1a6b153f5945800 (diff)
downloadtdebindings-3ed7c09d22a5f310a97516f5bab6068e5688a813.tar.gz
tdebindings-3ed7c09d22a5f310a97516f5bab6068e5688a813.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'korundum/rubylib/examples/rbTDEHTMLPart.rb')
-rw-r--r--korundum/rubylib/examples/rbTDEHTMLPart.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/korundum/rubylib/examples/rbTDEHTMLPart.rb b/korundum/rubylib/examples/rbTDEHTMLPart.rb
index 827dc157..55e2386c 100644
--- a/korundum/rubylib/examples/rbTDEHTMLPart.rb
+++ b/korundum/rubylib/examples/rbTDEHTMLPart.rb
@@ -26,7 +26,7 @@ additional code to make this do something useful. The
seem to provide much help. Also, to follow links, you
probably need to connect some signals to slots. I
haven't tried it, but this should work with a plain
-KMainWindow or other widget too.
+TDEMainWindow or other widget too.
The KDE website also incorporates gifs, jpegs, and
I believe CSS too. Playing around with some other
@@ -44,8 +44,8 @@ lifted from the KDE classref.
require 'Korundum'
# Note that we use KParts.MainWindow, not KMainWindow as the superclass
# (KParts.MainWindow subclasses KMainWindow). Also, be sure the 'apply'
# clause references KParts.MainWindow - it's a hard bug to track down
# if it doesn't.
@@ -44,8 +44,8 @@ lifted from the KDE classref.
require 'Korundum'
-# Note that we use KParts.MainWindow, not KMainWindow as the superclass
-# (KParts.MainWindow subclasses KMainWindow). Also, be sure the 'apply'
+# Note that we use KParts.MainWindow, not TDEMainWindow as the superclass
+# (KParts.MainWindow subclasses TDEMainWindow). Also, be sure the 'apply'
# clause references KParts.MainWindow - it's a hard bug to track down
# if it doesn't.